# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Union
from wordlift_client.models.query_coverage_output import QueryCoverageOutput
from typing import Optional, Set
from typing_extensions import Self

class AIVisibilityAnalysisResult(BaseModel):
    """
    AIVisibilityAnalysisResult
    """ # noqa: E501
    num_queries_requested: StrictInt
    coverage_threshold: Union[StrictFloat, StrictInt]
    entity_name: StrictStr
    query_reasoning: StrictStr
    covered_count: StrictInt
    total_queries: StrictInt
    query_details: List[QueryCoverageOutput]
    content_chunks_count: StrictInt
    coverage_score: Union[StrictFloat, StrictInt]
    __properties: ClassVar[List[str]] = ["num_queries_requested", "coverage_threshold", "entity_name", "query_reasoning", "covered_count", "total_queries", "query_details", "content_chunks_count", "coverage_score"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AIVisibilityAnalysisResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "coverage_score",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in query_details (list)
        _items = []
        if self.query_details:
            for _item in self.query_details:
                if _item:
                    _items.append(_item.to_dict())
            _dict['query_details'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AIVisibilityAnalysisResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "num_queries_requested": obj.get("num_queries_requested"),
            "coverage_threshold": obj.get("coverage_threshold"),
            "entity_name": obj.get("entity_name"),
            "query_reasoning": obj.get("query_reasoning"),
            "covered_count": obj.get("covered_count"),
            "total_queries": obj.get("total_queries"),
            "query_details": [QueryCoverageOutput.from_dict(_item) for _item in obj["query_details"]] if obj.get("query_details") is not None else None,
            "content_chunks_count": obj.get("content_chunks_count"),
            "coverage_score": obj.get("coverage_score")
        })
        return _obj


