# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.web_page_scrape_request import WebPageScrapeRequest

class TestWebPageScrapeRequest(unittest.TestCase):
    """WebPageScrapeRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebPageScrapeRequest:
        """Test WebPageScrapeRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebPageScrapeRequest`
        """
        model = WebPageScrapeRequest()
        if include_optional:
            return WebPageScrapeRequest(
                fetch_options = wordlift_client.models.web_page_import_fetch_options.WebPageImportFetchOptions(
                    block_ads = True, 
                    country_code = '', 
                    mode = 'default', 
                    premium_proxy = True, 
                    render_js = True, 
                    timeout = 56, 
                    wait_for = '', ),
                url = ''
            )
        else:
            return WebPageScrapeRequest(
                url = '',
        )
        """

    def testWebPageScrapeRequest(self):
        """Test WebPageScrapeRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
