# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.url_list_response import UrlListResponse

class TestUrlListResponse(unittest.TestCase):
    """UrlListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UrlListResponse:
        """Test UrlListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UrlListResponse`
        """
        model = UrlListResponse()
        if include_optional:
            return UrlListResponse(
                items = [
                    wordlift_client.models.url_list_item.UrlListItem(
                        url = '0', 
                        resource_type = 'page', 
                        is_enabled = True, 
                        status = '', 
                        last_run = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_success = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        score = 1.337, 
                        ttfb_ms = 1.337, 
                        response_time_ms = 1.337, )
                    ],
                page = wordlift_client.models.page_info.PageInfo(
                    limit = 56, 
                    cursor = '', ),
                links = {
                    'key' : ''
                    }
            )
        else:
            return UrlListResponse(
                items = [
                    wordlift_client.models.url_list_item.UrlListItem(
                        url = '0', 
                        resource_type = 'page', 
                        is_enabled = True, 
                        status = '', 
                        last_run = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_success = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        score = 1.337, 
                        ttfb_ms = 1.337, 
                        response_time_ms = 1.337, )
                    ],
                page = wordlift_client.models.page_info.PageInfo(
                    limit = 56, 
                    cursor = '', ),
                links = {
                    'key' : ''
                    },
        )
        """

    def testUrlListResponse(self):
        """Test UrlListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
