# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.site_files import SiteFiles

class TestSiteFiles(unittest.TestCase):
    """SiteFiles unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SiteFiles:
        """Test SiteFiles
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SiteFiles`
        """
        model = SiteFiles()
        if include_optional:
            return SiteFiles(
                status = 'Excellent',
                explanation = '',
                robots_txt = 'found',
                llms_txt = 'found',
                bot_access = wordlift_client.models.site_files_bot_access.SiteFiles_botAccess(
                    gptbot = 'allowed', 
                    claude = 'allowed', 
                    googlebot = 'allowed', )
            )
        else:
            return SiteFiles(
        )
        """

    def testSiteFiles(self):
        """Test SiteFiles"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
