# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.url_results_response import UrlResultsResponse

class TestUrlResultsResponse(unittest.TestCase):
    """UrlResultsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UrlResultsResponse:
        """Test UrlResultsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UrlResultsResponse`
        """
        model = UrlResultsResponse()
        if include_optional:
            return UrlResultsResponse(
                url = '0',
                run_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                processed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                results = [
                    wordlift_client.models.monitor_result_item.MonitorResultItem(
                        monitor_name = '', 
                        state = 'OK', 
                        details = '', 
                        score = 1.337, 
                        metadata = { }, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        processed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return UrlResultsResponse(
                url = '0',
                results = [
                    wordlift_client.models.monitor_result_item.MonitorResultItem(
                        monitor_name = '', 
                        state = 'OK', 
                        details = '', 
                        score = 1.337, 
                        metadata = { }, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        processed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testUrlResultsResponse(self):
        """Test UrlResultsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
