# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.url_summary_response import UrlSummaryResponse

class TestUrlSummaryResponse(unittest.TestCase):
    """UrlSummaryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UrlSummaryResponse:
        """Test UrlSummaryResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UrlSummaryResponse`
        """
        model = UrlSummaryResponse()
        if include_optional:
            return UrlSummaryResponse(
                url = '0',
                status = '',
                last_run = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                score = 1.337,
                ttfb_ms = 1.337,
                response_time_ms = 1.337,
                monitors = [
                    wordlift_client.models.monitor_summary_item.MonitorSummaryItem(
                        name = '', 
                        state = 'OK', 
                        details = '', 
                        score = 1.337, )
                    ],
                neighbors = wordlift_client.models.neighbors.Neighbors(
                    previous = '0', 
                    next = '0', )
            )
        else:
            return UrlSummaryResponse(
                url = '0',
                status = '',
                monitors = [
                    wordlift_client.models.monitor_summary_item.MonitorSummaryItem(
                        name = '', 
                        state = 'OK', 
                        details = '', 
                        score = 1.337, )
                    ],
                neighbors = wordlift_client.models.neighbors.Neighbors(
                    previous = '0', 
                    next = '0', ),
        )
        """

    def testUrlSummaryResponse(self):
        """Test UrlSummaryResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
