# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.ai_visibility_analysis_result import AIVisibilityAnalysisResult

class TestAIVisibilityAnalysisResult(unittest.TestCase):
    """AIVisibilityAnalysisResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AIVisibilityAnalysisResult:
        """Test AIVisibilityAnalysisResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AIVisibilityAnalysisResult`
        """
        model = AIVisibilityAnalysisResult()
        if include_optional:
            return AIVisibilityAnalysisResult(
                url = '',
                num_queries_requested = 56,
                coverage_threshold = 1.337,
                entity_name = '',
                query_reasoning = '',
                covered_count = 56,
                total_queries = 56,
                query_details = [
                    wordlift_client.models.query_coverage.QueryCoverage(
                        query = '', 
                        is_covered = True, 
                        similarity = 1.337, 
                        best_chunk_preview = '', )
                    ],
                content_chunks_count = 56,
                coverage_score = 1.337
            )
        else:
            return AIVisibilityAnalysisResult(
                url = '',
                num_queries_requested = 56,
                coverage_threshold = 1.337,
                entity_name = '',
                query_reasoning = '',
                covered_count = 56,
                total_queries = 56,
                query_details = [
                    wordlift_client.models.query_coverage.QueryCoverage(
                        query = '', 
                        is_covered = True, 
                        similarity = 1.337, 
                        best_chunk_preview = '', )
                    ],
                content_chunks_count = 56,
                coverage_score = 1.337,
        )
        """

    def testAIVisibilityAnalysisResult(self):
        """Test AIVisibilityAnalysisResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
