# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from wordlift_client.models.resource_type import ResourceType
from typing import Optional, Set
from typing_extensions import Self

class UrlListItem(BaseModel):
    """
    UrlListItem
    """ # noqa: E501
    url: Annotated[str, Field(min_length=1, strict=True, max_length=2083)]
    resource_type: ResourceType
    is_enabled: StrictBool
    status: StrictStr
    last_run: Optional[datetime] = None
    last_success: Optional[datetime] = None
    score: Optional[Union[StrictFloat, StrictInt]] = None
    ttfb_ms: Optional[Union[StrictFloat, StrictInt]] = None
    response_time_ms: Optional[Union[StrictFloat, StrictInt]] = None
    __properties: ClassVar[List[str]] = ["url", "resource_type", "is_enabled", "status", "last_run", "last_success", "score", "ttfb_ms", "response_time_ms"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UrlListItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if last_run (nullable) is None
        # and model_fields_set contains the field
        if self.last_run is None and "last_run" in self.model_fields_set:
            _dict['last_run'] = None

        # set to None if last_success (nullable) is None
        # and model_fields_set contains the field
        if self.last_success is None and "last_success" in self.model_fields_set:
            _dict['last_success'] = None

        # set to None if score (nullable) is None
        # and model_fields_set contains the field
        if self.score is None and "score" in self.model_fields_set:
            _dict['score'] = None

        # set to None if ttfb_ms (nullable) is None
        # and model_fields_set contains the field
        if self.ttfb_ms is None and "ttfb_ms" in self.model_fields_set:
            _dict['ttfb_ms'] = None

        # set to None if response_time_ms (nullable) is None
        # and model_fields_set contains the field
        if self.response_time_ms is None and "response_time_ms" in self.model_fields_set:
            _dict['response_time_ms'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UrlListItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "url": obj.get("url"),
            "resource_type": obj.get("resource_type"),
            "is_enabled": obj.get("is_enabled"),
            "status": obj.get("status"),
            "last_run": obj.get("last_run"),
            "last_success": obj.get("last_success"),
            "score": obj.get("score"),
            "ttfb_ms": obj.get("ttfb_ms"),
            "response_time_ms": obj.get("response_time_ms")
        })
        return _obj


